from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker, scoped_session
import logging

# Add logger configuration
logger = logging.getLogger(__name__)

# Create engine and session factory
engine = create_engine('sqlite:///messages.db')
session_factory = sessionmaker(bind=engine)
Session = scoped_session(session_factory)

# Create base class
Base = declarative_base()
Base.query = Session.query_property()  # Add query property to all models

def initialize_database():
    from models.timestamp_tracker import TimestampTracker
    from datetime import datetime
    
    # Drop and recreate all tables
    # Base.metadata.drop_all(engine)  # This will drop all existing tables
    Base.metadata.create_all(engine)  # This will create all tables with updated schema
    
    try:
        # Check if timestamp exists
        timestamp_entry = Session.query(TimestampTracker).first()
        if not timestamp_entry:
            # Create initial timestamp entry
            initial_timestamp = datetime.strptime('2025-04-03T00:35:29', '%Y-%m-%dT%H:%M:%S')
            timestamp_entry = TimestampTracker(last_timestamp=initial_timestamp)
            Session.add(timestamp_entry)
            Session.commit()
    except Exception as e:
        Session.rollback()
        raise e
    finally:
        Session.close()